
Changelog
=========

1.0.3 (2018-04-05)
-----------------------------------------
* Updated badges and added DOI
* Added tests for python 3.6
* Removed tests for python 3.3
* Made some PEP8 changes

1.0.2 (2018-02-27)
-----------------------------------------

* Extend character limit for allowable data file path, and update documentation
  to reflect a change in maintainers.  Also updated testing implimentation,
  reduced fortran compiler warnings, and improved PEP8 compliance.

1.0.1 (2016-03-10)
-----------------------------------------

* Remove geocentric to geodetic conversion of subsolar point based on feedback
  from Art Richmond. (The subsolar point is the same in geocentric and geodetic
  coordinates.) The helper function `gc2gdlat` have been kept to preserve
  backwards compatibility.


1.0.0 (2015-11-30)
-----------------------------------------

* Initial release
